
import java.awt.*;

public class ColorChooser
{
	protected interface ColorChooseable
	{
		public Color getColor();
		public boolean isSuitable(double d);
	}

	protected enum Colors implements ColorChooseable
	{
		RED(Color.red)
		{
			public boolean isSuitable(double d)
			{
				if (151 <= d)
				{
					return true;
				}
				return false;
			}
		},
		ORANGE(Color.orange, 101, 150),
		YELLOW(Color.yellow,  51, 100),
		GREEN(Color.green,     1,  50),
		BLUE(Color.blue)
		{
			public boolean isSuitable(double d)
			{
				if (d <= 0)
				{
					return true;
				}
				return false;
			}
		};

		private Color color;
		private double min;
		private double max;

		Colors(Color color)
		{
			this.color = color;
		}

		Colors(Color color, double min, double max)
		{
			this.color = color;
			this.min = min;
			this.max = max;
		}

		public Color getColor()
		{
			return color;
		}

		public boolean isSuitable(double d)
		{
			if (min <= d && d <= max)
			{
				return true;
			}
			return false;
		}
	}

	public ColorChooseable[] getColorChooseables()
	{
		return Colors.values();
	}

	public Color choose(double d) throws IllegalArgumentException
	{
		for (ColorChooseable cc : this.getColorChooseables())
		{
			if (cc.isSuitable(d))
			{
				return cc.getColor();
			}
		}

		throw new IllegalArgumentException("" + d);
	}
}
