
import java.awt.*;
import java.util.*;

import javax.swing.*;
import javax.swing.plaf.*;

public class MainFrame extends JFrame
{
	private int[] values;
	private double average;

	public MainFrame(int[] values)
	{
		if (values.length != 9)
		{
			throw new IllegalArgumentException(Arrays.toString(values));
		}

		this.values = values;

		double sum = 0;
		for (int n : values)
		{
			sum += n;
		}
		average = sum / values.length;

		this.init();
	}

	public void init()
	{
		JPanel panel = new JPanel();

		panel.setLayout(new GridLayout(3, 3));
		ColorChooser cc = new ColorChooser();
		for (int i = 0; i < 9; i++)
		{
			panel.add(new JPanel()).setBackground(cc.choose(values[i] - average));
		}

		MathVector vector = new MathVector(new Point(0, 0));
		int adeg = 45;
		int[] degs =
		{
			3,  2, 1,
			4, -1, 0,
			5,  6, 7
		};

		for (int i = 0 ; i < 9; i++)
		{
			if (degs[i] >= 0)
			{
				vector = vector.add(new MathVector(values[i] - values[4], StrictMath.toRadians(degs[i] * adeg)));
			}
		}

		LayerUI<JPanel> lui = new VectorLayerUI<>(vector);
		JLayer<JPanel> jl = new JLayer<>(panel, lui);

		this.add(jl);
	}
}
